import {Injectable} from '@angular/core';
import {JSONRequest} from '../../interface/JSONRequest';
import {HttpClient} from '@angular/common/http';
import {HttpInterface} from '../../interface/HttpInterface';
import {catchError} from 'rxjs/operators';
import {Observable} from 'rxjs';
import {LoginResponse, LogoutResponse} from '../../interface/Response';

@Injectable({
  providedIn: 'root'
})
export class LoginService extends JSONRequest {

  constructor(
    private http: HttpClient,
  ) {
    super();
  }

  /**
   * 注销登录
   */
  logout(body): Observable<LogoutResponse> {
    return this.http.post<LogoutResponse>(HttpInterface.logout, body, this.httpOptions)
      .pipe(
        catchError(this.handleError<any>('注销'))
      );
  }

  /**
   * 登陆
   */
  login(body): Observable<LoginResponse> {
    return this.http.post<LoginResponse>(HttpInterface.login, body, this.httpOptions)
      .pipe(
        catchError(this.handleError<any>('登陆'))
      );
  }
}
