import {BrowserModule} from '@angular/platform-browser';
import {NgModule} from '@angular/core';

import {AppRoutingModule} from './app-routing.module';
// 主框架
import {AppComponent} from './app.component';
// 国际化支持
import {TranslateLoader, TranslateModule} from '@ngx-translate/core';
import {TranslateHttpLoader} from '@ngx-translate/http-loader';
// cookie
import {CookieService} from 'ngx-cookie-service';
// 异常处理组件
import {ErrorComponent} from './error/error.component';
// 账号管理模块
import {AccountModule} from './account/account/account.module';
// 论坛模块
import {ForumModule} from './forum/forum.module';
// 访客管理模块
import {VisitorModule} from './visitor/visitor.module';
// Http请求模块
import {HttpClient, HttpClientModule} from '@angular/common/http';
import {HtmlPipe} from './html.pipe';
import {FormsModule} from '@angular/forms';
import {PageModule} from './page/page/page.module';

export function HttpLoaderFactory(http: HttpClient) {
  return new TranslateHttpLoader(http);
}

/**
 * 应用入口
 */
@NgModule({
  declarations: [
    AppComponent,
    ErrorComponent,
    HtmlPipe,
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    AccountModule,
    ForumModule,
    VisitorModule,
    PageModule,
    HttpClientModule,
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: HttpLoaderFactory,
        deps: [HttpClient]
      }
    }),
    FormsModule
  ],
  providers: [CookieService],
  bootstrap: [AppComponent]
})
export class AppModule {
}
